@@ -1,4 +1,5 @@
 import shutil
+import shlex
 import subprocess
 from pynonymizer.database.exceptions import DependencyError
 import os
@@ -7,12 +8,13 @@ Seperate everything that touches actual query exec into its own module
 """
 
 class PSqlDumpRunner:
-    def __init__(self, db_host, db_user, db_pass, db_name, db_port="5432"):
+    def __init__(self, db_host, db_user, db_pass, db_name, db_port="5432", additional_opts = ""):
         self.db_host = db_host
         self.db_user = db_user
         self.db_pass = db_pass
         self.db_name = db_name
         self.db_port = db_port
+        self.additional_opts = shlex.split(additional_opts)
 
         if not (shutil.which("pg_dump")):
             raise DependencyError( "pg_dump", "The 'pg_dump' client must be present in the $PATH")
@@ -27,19 +29,20 @@ class PSqlDumpRunner:
         return new_env
 
     def open_dumper(self):
-        return subprocess.Popen(self.__get_base_params() + [self.db_name],
+        return subprocess.Popen(self.__get_base_params() + self.additional_opts + [self.db_name],
                                 stdout=subprocess.PIPE,
                                 env=self.__get_env()
                                 ).stdout
 
 
 class PSqlCmdRunner:
-    def __init__(self, db_host, db_user, db_pass, db_name, db_port="5432"):
+    def __init__(self, db_host, db_user, db_pass, db_name, db_port="5432", additional_opts = ""):
         self.db_host = db_host
         self.db_user = db_user
         self.db_pass = db_pass
         self.db_name = db_name
         self.db_port = db_port
+        self.additional_opts = shlex.split(additional_opts)
 
         if not (shutil.which("psql")):
             raise DependencyError("psql", "The 'psql' client must be present in the $PATH")
@@ -60,7 +63,7 @@ class PSqlCmdRunner:
         outputs = []
 
         for statement in statements:
-            outputs.append( subprocess.check_output(self.__get_base_params() + ["--command", statement], env=self.__get_env()) )
+            outputs.append( subprocess.check_output(self.__get_base_params() + self.additional_opts + ["--command", statement], env=self.__get_env()) )
 
         return outputs
 
@@ -72,7 +75,7 @@ class PSqlCmdRunner:
         
         for statement in statements:
             outputs.append(subprocess.check_output(
-                self.__get_base_params() + ["--dbname", self.db_name,  "--command", statement],
+                self.__get_base_params() + ["--dbname", self.db_name, *self.additional_opts,  "--command", statement],
                 env=self.__get_env()
             ))
 
@@ -80,14 +83,14 @@ class PSqlCmdRunner:
 
     def get_single_result(self, statement):
         return subprocess.check_output(
-            self.__get_base_params() + ["--dbname", self.db_name, "-tA", "--command", statement],
+            self.__get_base_params() + ["--dbname", self.db_name, "-tA", *self.additional_opts, "--command", statement],
             env=self.__get_env()
         ).decode()
 
 
     def open_batch_processor(self):
         return subprocess.Popen(
-            self.__get_base_params() + ["--dbname", self.db_name, "--quiet"],
+            self.__get_base_params() + ["--dbname", self.db_name, "--quiet"] + self.additional_opts,
             env=self.__get_env(),
             stdin=subprocess.PIPE
         ).stdin
